function add_col_csv(col_data, col_name, sequence, groundtruth_filename_input, groundtruth_filename_output)
%ADD_COL_CSV
%   This function appends the column COL_DATA with the name COL_NAME
%   to the CSV file GROUNDTRUTH_FILENAME_INPUT and writes the result to
%   GROUNDTRUTH_FILENAME_OUTPUT. Of the column exists, it is replaced.
%
%   Parameters:
%     COL_DATA is the column data to be written
%     COL_NAME is the header name of the column to be written
%     GROUNDTRUTH_FILENAME_INPUT is input CSV data filename
%     GROUNDTRUTH_FILENAME_OUTPUT is output CSV data filename
%
% Copyright (c) MVTec Software GmbH.  All rights reserved.
%
% All use of this software is subject to the terms of the revised BSD
% license.  You should have received a copy of this license along
% with this source code in a file named "license.txt."

% Set the default file names if none are passed
if (nargin < 4)
    groundtruth_filename_input  = 'groundtruth_baseline.csv';
    groundtruth_filename_output = 'groundtruth_baseline_trackers.csv';
elseif (nargin < 5)
    groundtruth_filename_output = groundtruth_filename_input;
end

%% First we read the CSV file...
CSVData = read_csv(sequence, groundtruth_filename_input);

% Test if the input data is consistent with the existing CSV data
csv_field_names = fieldnames(CSVData);
NumRows = length(CSVData.(csv_field_names{1}));

if (NumRows ~= length(col_data))
    error('The column data is not consistent with CSVData');
end


%% ...then we add the column. If its numerical, we convert it to a string
% Please note: If the field already exists, it is merely replaced!
if (~iscellstr(col_data))
    string_data = cell(NumRows,1);
    for idx = 1:NumRows
        string_data{idx} = ['[',strjoin(arrayfun(@(x) num2str(x),...
                       col_data(idx,:),'UniformOutput',false),...
                       ','),']'];
    end
    col_data = string_data;
end
CSVData.(col_name) = col_data;
 
%% And finally we write out the new data
write_csv(CSVData, sequence, groundtruth_filename_output);
end
