function [images, groundtruth] = read_groundtruth_csv(sequence,groundtruth_type)
%READ_GROUNDTRUTH_CSV 
%   This function reads the groundtruth regions and the image paths from
%   CSV file. 
%
%   Parameters:
%     SEQUENCE is the location of the image files (must end with a slash
%      '/' or '\').
%     GROUNDTRUTH_TYPE (optional) The type of groundtruth
%      (smallest_rectangle1, best_rectangle1, best_rectangle2, 
%       vot2016, vot2015,vot2014,...)
%
%   Outputs:
%     IMAGES Paths to the image the passed sequence.
%     GROUNDTRUTH The groundtruths for the passed sequence
%
% Copyright (c) MVTec Software GmbH.  All rights reserved.
%
% All use of this software is subject to the terms of the revised BSD
% license.  You should have received a copy of this license along
% with this source code in a file named "license.txt."

if nargin<=2
    % If available the default groundtruth data is the vot2016 data
    % if its not availible in the csv file, we use the smallest
    % rectangle1 of the segmentation. We have this here since
    % other datasets, e.g. DAVIS, do not have vot groudntruth data.
    groundtruth_type = 'vot2016';
    groundtruth_type_fallback = 'theoretical_smallest_rectangle1';
end

groundtruth_filename = 'groundtruth_baseline.csv';

filename = fullfile(sequence,groundtruth_filename);
[CSVData] = import_csv_file(filename);

images = CSVData.ImageFile;

if (isfield(CSVData,groundtruth_type))
    groundtruth = CSVData.(groundtruth_type);
else
    % If the groundtruth_type is not available use the fallback, otherwise
    % raise an error
    if (~isfield(CSVData,groundtruth_type_fallback))
        error(['groundtruth_type and fallback groundtruth_type '...
               'are not present']);
    end
    warning('%s groundtruth not available -> %s used', ...
            groundtruth_type, groundtruth_type_fallback);
    groundtruth = CSVData.(groundtruth_type_fallback);
end

end