function write_csv(CSVData, sequence,groundtruth_filename)
%WRITE_CSV 
%   This function write CSVData to GROUNDTRUTH_FILENAME in the SEQUENCE
%   folder
%
%   Parameters:
%     CSVData input struct data to be written
%     SEQUENCE is the location of the image sequence
%     GROUNDTRUTH_FILENAME output filename
%
% Copyright (c) MVTec Software GmbH.  All rights reserved.
%
% All use of this software is subject to the terms of the revised BSD
% license.  You should have received a copy of this license along
% with this source code in a file named "license.txt."

if (nargin < 3)
    groundtruth_filename = 'groundtruth_baseline.csv';
end
filename = fullfile(sequence,groundtruth_filename);

% First we write the header with fprintf
csv_field_names = fieldnames(CSVData);
header_out = char(csv_field_names);
fid = fopen(filename, 'w');
for idx = 1:size(header_out,1)-1
    fprintf(fid, '%s;', strtrim(header_out(idx,:)));
end
fprintf(fid, '%s', strtrim(header_out(size(header_out,1),:)));
fprintf(fid, '\n');

% Its a bit messy at the moment. We have strings in the single
% cells of the csv file. Hence we need to write our data with
% fprintf and not with csvwrite or dlmwrite. Otherwise other csv io
% interfaces has problems with array data in a single cell. 
NumRows = length(CSVData.(csv_field_names{1}));

for idx = 1:NumRows
    for jdx = 1:size(header_out,1)-1
        fprintf(fid, '%s;', CSVData.(csv_field_names{jdx}){idx});
    end
    fprintf(fid, '%s', CSVData.(csv_field_names{size(header_out,1)}){idx});
    fprintf(fid, '\n');
end
fclose(fid);

end