% Test the conversion of vot regions (region):
%        [row1, col1, row2, col2, row3, col3, row4, col4 (,row1, col1)]
%         or
%        [row1, col1, height, width]
% to box_param (box_param):
%        [row, col, width, height, phi]
% and vis-versa.
%
% Copyright (c) MVTec Software GmbH.  All rights reserved.
%
% All use of this software is subject to the terms of the revised BSD
% license.  You should have received a copy of this license along
% with this source code in a file named "license.txt."

%% Test convert_region2box_param and convert_box_param2region
for idx = 1:100
   % generate a random rectangle with box param
   box_param = rand(1,5) .* [512,512,300,300,180] - [0, 0, 0, 0, 90];
   % We consolidate the aprameaters to ensure the angle is between -45;45
   box_param = consolidate_box_param(box_param);
   
   % convert to region
   region = convert_box_param2region(box_param);
   
   % convert back to b
   box_param2 = convert_region2box_param(region);
   
   % compare both parametrizations
   if (sum(abs(box_param - box_param2)) > 1e-12)
       error('The forward/backward conversion is not zero');   
   end
end

%% Test convert_box_param2region and convert_region2box_param with 4 parameter region
for idx = 1:100
   % generate a random rectangle with box_param
   region = rand(1,4) .* [512,512,300,300];
   
   % convert to box_param
   box_param = convert_region2box_param(region);
   
   % convert back to region
   region2 = convert_box_param2region(box_param);
   
   % we calculcate the four corner points of the 4 point region:
   region5pts = [region(:,1),region(:,2),region(:,1)+region(:,3),region(:,2),...
                 region(:,1)+region(:,3),region(:,2)+region(:,4),...
                 region(:,1),region(:,2)+region(:,4),...
                 region(:,1),region(:,2)];

   % compare both parametrizations - because we make no restriction on the
   % order of the 5 points, we check if we have the same unique points.
   % There should be 4 of them!
   if (sum(abs(sort(unique(region5pts)) - sort(unique(region2)))) > 1e-12 && ...
       length(sort(unique(region5pts))) ~= 4)
       error('The forward/backward conversion is not zero');   
   end   
end

%% Test convert_box_param2region and convert_region2box_param with 10 parameter region
for idx = 1:100
   % generate a random rectangle with box_param
   region = rand(1,4) .* [512,512,300,300];
   region5pts = [region(:,1),region(:,2),region(:,1)+region(:,3),region(:,2),...
                 region(:,1)+region(:,3),region(:,2)+region(:,4),...
                 region(:,1),region(:,2)+region(:,4),...
                 region(:,1),region(:,2)];
   
   % convert to box_param
   box_param = convert_region2box_param(region5pts);
   
   % convert back to region
   region2 = convert_box_param2region(box_param);
   
   % compare both parametrizations - because we make no restriction on the
   % order of the 5 points, we check if we have the same unique points.
   % There should be 4 of them!
   if (sum(abs(sort(unique(region5pts)) - sort(unique(region2)))) > 1e-12 && ...
       length(sort(unique(region5pts))) ~= 4)
       error('The forward/backward conversion is not zero');   
   end   
end