function [box_param] = consolidate_box_param(box_param)
%CONSOLIDATE_BOX_PARAM
%   Unifies the angle range of box coordinates to be
%          between (-45:45] degrees.
%
%   Parameters:
%     BOX_PARAM box coordinates [row,col,width,height,phi]
%
%   Outputs:
%     BOX_PARAM box coordinates [row,col,width,height,phi]
%
% Copyright (c) MVTec Software GmbH.  All rights reserved.
%
% All use of this software is subject to the terms of the revised BSD
% license.  You should have received a copy of this license along
% with this source code in a file named "license.txt."

phi = box_param(:,5);

% First lets get rid of all 360 degree permutations
phi = mod(phi, 360.0);

% Now we ensure our rotation is in (-180:180].
% We don't need to flip the lengths, we just flip the angle
phi(phi > 180.0)   = phi(phi > 180.0)   - 360.0;
phi(phi <= -180.0) = phi(phi <= -180.0) + 360.0;

% Alright, now we have an angle between -(180:180]. We have the follow cases:
% phi in (-180:-135] => phi_new = phi + 180.0   NO FLIP
% phi in (-135: -45] => phi_new = phi + 90      FLIP
% phi in ( -45:  45] => DO NOTHING
% phi in (  45: 135] => phi_new = phi - 90      FLIP
% phi in ( -135: 180] => phi_new = phi - 180.0   NO FLIP
FLIP = (phi > -135 & phi <= -45) | (phi > 45 & phi <= 135);
phi(phi <= -135)              = phi(phi <= -135)    + 180.0;
phi(phi <= -45)               = phi(phi <= -45)     + 90.0;
phi((phi > 45 & phi <= 135))  = phi((phi > 45 & phi <= 135)) - 90.0;
phi(phi > 135)                = phi(phi > 135) - 180.0;

% Set output and flip if necessary
box_param(:,5) = phi;
tmp = box_param(FLIP,3);
box_param(FLIP,3) = box_param(FLIP,4);
box_param(FLIP,4) = tmp;