function [region] = convert_box_param2region(box_param)
%CONVERT_BOX_PARAM2REGION
%   Convert bounding box coordinates to vot regions points 
%
%   Parameters:
%     BOX_PARAM box coordinates [row,col,width,height,phi]
%
%   Outputs:
%     REGION box coordinates [row1,col1,row2,col2,row3,col3,row4,col4]
%
% Copyright (c) MVTec Software GmbH.  All rights reserved.
%
% All use of this software is subject to the terms of the revised BSD
% license.  You should have received a copy of this license along
% with this source code in a file named "license.txt."

%% Prepare box parameters
if (ischar(box_param))
    % We need to use str2num here, str2double can't handle '[x,y,...]'
    box_param = str2num(box_param);
end

%% Calculate region
% Get the individual  box parameters
row = box_param(:,1);
col = box_param(:,2);
width = box_param(:,3);
height = box_param(:,4);
phi = deg2rad(box_param(:,5));

% Calculate four corner points:
co = cos(phi);
si = sin(phi);
l1 = (width - 1)/2.0;
l2 = (height - 1)/2.0;
co1 = co * l1;
co2 = co * l2;
si1 = si * l1;
si2 = si * l2;

col1 =  co1 - si2 + col;
row1 = -si1 - co2 + row;
col2 = -co1 - si2 + col;
row2 =  si1 - co2 + row;
col3 = -co1 + si2 + col;
row3 =  si1 + co2 + row;
col4 =  co1 + si2 + col;
row4 = -si1 + co2 + row;

% HDevelop and Matlab have swapped image axes and HDevelop axes start at (0,0)
% => (row_hdev + 1, col_hdev + 1) = (col_matlab, row_matlab)
region = [col1,row1,col2,row2,col3,row3,col4,row4,col1,row1];

region = region + 1.0;
