#!/usr/bin/env python

# --------------------------------------------------------
# File: evaluate_tracker_accuracy.py
# Copyright (c) MVTec Software GmbH.  All rights reserved.
#
# All use of this software is subject to the terms of the revised BSD
# license.  You should have received a copy of this license along
# with this source code in a file named "license.txt."
# --------------------------------------------------------

"""
This script starts an application that allows to
    - evaluate the absolute and relative accuracy of trackers
      and display the relative and absolut IoU
    - show sequences completely or frame by frame

See readme.txt for installation instructions before running.
"""

import argparse
from mvtec_tracker_eval_app import TrackerEvaluationApp
from mvtec_config import cfg, cfg_from_file
import os

fmt_str = "{0:23} {1}"


def parse_args():
    """Parse input arguments."""
    parser = argparse.ArgumentParser(
        description='Evaluate the Accuracy of Trackers',
        formatter_class=argparse.ArgumentDefaultsHelpFormatter)
    parser.add_argument('--cfg', type=str,
                        help="Config file to use in order to overwrite the "
                             "default settings. If None is specified, default "
                             "settings are used.",
                        default=None)

    args = parser.parse_args()

    return args


if __name__ == '__main__':

    print "Evaluate the Accuracy of Trackers"

    # Parse the input arguments
    args = parse_args()

    if args.cfg is not None:
        cfg_from_file(args.cfg)

    # Get the base folder
    print fmt_str.format('DATASET BASE IMAGE FOLDER:',
                         os.path.join(cfg.BASE_DIR, cfg.IMAGE_DIR))
    print fmt_str.format('DATASET BASE ANNOTATIONS FOLDER:',
                         os.path.join(cfg.BASE_DIR, cfg.ANNOT_DIR))

    # We call our evaluation app
    app = TrackerEvaluationApp(cfg)
    app.root.mainloop()
