#!/bin/bash
# Copyright (c) MVTec Software GmbH.  All rights reserved.
#
# All use of this software is subject to the terms of the revised BSD
# license.  You should have received a copy of this license along
# with this source code in a file named "license.txt."

# This script requires unzip.  If the unzip command isn't already installed on your system, then run:
# 
# sudo apt-get install unzip

##############################
# Download DAVIS and votseg  #
##############################
SCRIPTPATH="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
# DAVIS 2016 dataset
#
# A Benchmark Dataset and Evaluation Methodology for Video Object Segmentation
# F. Perazzi, J. Pont-Tuset, B. McWilliams, L. Van Gool, M. Gross, and A. Sorkine-Hornung
# Computer Vision and Pattern Recognition (CVPR) 2016
#
# see http://davischallenge.org/
# for details.
if [ ! -d "$SCRIPTPATH/DAVIS" ]
then
	wget https://graphics.ethz.ch/Downloads/Data/Davis/DAVIS-data.zip -P $SCRIPTPATH
	mkdir -p $SCRIPTPATH/DAVIS
	unzip $SCRIPTPATH/DAVIS-data -d $SCRIPTPATH/DAVIS
fi
# votseg 2016 dataset
#
# Pixel-Wise Object Segmentations for the {VOT} 2016 Dataset
# Vojir, Tomas and Matas, Jiri, Research Report, 2016
#
# see http://cmp.felk.cvut.cz/~vojirtom/dataset/votseg/index.html
# and http://www.votchallenge.net/vot2016/dataset.html
# for details.
if [ ! -d "$SCRIPTPATH/votseg" ]
then
	wget http://cmp.felk.cvut.cz/~vojirtom/dataset/votseg/data/votseg_dataset.zip -P $SCRIPTPATH
	mkdir -p $SCRIPTPATH/votseg
	mkdir -p $SCRIPTPATH/votseg/annotations
	unzip $SCRIPTPATH/votseg_dataset -d $SCRIPTPATH/votseg/annotations
	wget http://data.votchallenge.net/vot2016/vot2016.zip -P $SCRIPTPATH
	mkdir -p $SCRIPTPATH/votseg/images
	unzip $SCRIPTPATH/vot2016 -d $SCRIPTPATH/votseg/images
fi

#########################
#  Copy the .csv files  #
#########################
# Copy the .csv files to the image folders.
cp -r $SCRIPTPATH/../annotations/DAVIS/* $SCRIPTPATH/DAVIS/DAVIS/JPEGImages/
cp -r $SCRIPTPATH/../annotations/votseg/* $SCRIPTPATH/votseg/images/

############
# Clean up #
############
if [ -f "$SCRIPTPATH/DAVIS-data.zip" ]
then
	rm $SCRIPTPATH/DAVIS-data.zip
fi
if [ -f "$SCRIPTPATH/votseg_dataset.zip" ]
then
	rm $SCRIPTPATH/votseg_dataset.zip
fi
if [ -f "$SCRIPTPATH/vot2016.zip" ]
then
	rm $SCRIPTPATH/vot2016.zip
fi